/******************************************************************************
 *
 * FILE: saradc.c
 *
 * Description:
 *    SAR ADC conversion
 *
 * History:
 *    17.11.2017   PN   Initial version
 *    12.02.2018   MF   Update for SPC574K72
 *
 ******************************************************************************
 * Copyright (C) 2015-2017 HighTec EDV-Systeme GmbH.  All rights reserved.
 *
 * This is proprietary software. Any use of the software requires a written
 * license agreement with HighTec EDV-Systeme GmbH. Please contact for
 * detailed license information: info@hightec-rt.com.
 *****************************************************************************/

#ifndef SARADC_H
#define SARADC_H

/* ============================================================================
 * SARADC EXAMPLE SETTING
 * User ** can ** change it, here in this file
 * ==========================================================================*/

/* ============================================================================
 * SARADC, PIN INSTANCES IMPLEMENTATION
 * Only relevant configuration for SARADC example
 * ==========================================================================*/

/* SARADC ports */
#define SARADC_PIN_PB0		16

/* SAR ADC Module clock from AUX */
#define SARADC_SYS_CLOCK   UC_SARADC_CLK /* The clock is set via BSP during
                                            platform initialization.*/

/* SAR ADC ISR Vector (base vector for subsequent channels) */
#define UC_SARADCB_ISR 543

/* SARADC B bit resolution 12 */
#define SARADC_CTR0_CRES    0 /* 0: 12-bit resolution CTR[0].B.CRES */

/* SARADC B sample time, see DS chapter "SAR ADC electrical specification" */
#define SARADC_B_SAMPLE_TIME_MIN      500 /* [ns] slow 12-bit configuration */

/* ============================================================================
 * SARADC EXTERN
 * ==========================================================================*/

extern uint32_t g_saradc_result_uint;  /* ADC result in uint32 */
extern float 	g_saradc_result_volts; /* ADC result in float [volts] */

/* ============================================================================
 * SARADC API INTERFACE
 * ==========================================================================*/

void saradc_Init(void);
void saradc_StartScan (void);

/* ============================================================================
 * ASRADC B CONFIGURATION
 * Example ADCSAR setting
 * ==========================================================================*/

#define SARADC_B_CTR0_INPSAMP  \
	    (((SARADC_B_SAMPLE_TIME_MIN * SARADC_SYS_CLOCK)/1000)+1)

/* ============================================================================
 * SARADC CONFIGURATION CHECKS
 * ==========================================================================*/

/* Sample time configuration is in range */
#if ((SARADC_B_CTR0_INPSAMP < 5) || (SARADC_B_CTR0_INPSAMP > 255))
#error Incorrect sample time, check the SARADC system clock
#endif

#endif /* SARADC_H */
